__version__ = "3.2.1"
__license__ = "MIT"
__author__ = "yu9824"
__copyright__ = "Copyright © 2021 yu9824"
__url__ = "http://github.com/yu9824/ternary-diagram/"

from ._api import TernaryDiagram

__all__ = ("TernaryDiagram",)
